@@ -8,8 +8,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017 The Sympa Community. See the AUTHORS.md file at the top-level
-# directory of this distribution and at
+# Copyright 2017, 2018 The Sympa Community. See the AUTHORS.md file at the
+# top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -434,7 +434,7 @@ our @params = (
         'gettext_id' => 'Fork threshold of bulk daemon',
         'file'       => 'sympa.conf',
         'gettext_comment' =>
-            'The minimum number of packets before bulk daemon forks the new worker to increase sending rate.',
+            'The minimum number of packets before bulk daemon forks a new worker to increase sending rate.',
     },
     {   'name'       => 'bulk_max_count',
         'default'    => '3',
@@ -446,7 +446,7 @@ our @params = (
         'gettext_id' => 'Idle timeout of bulk workers',
         'file'       => 'sympa.conf',
         'gettext_comment' =>
-            'The number of seconds a bulk worker will remain running without processing a message before it spontaneously exists.',
+            'The number of seconds a bulk worker will remain running without processing a message before it spontaneously exits.',
         'gettext_unit' => 'seconds',
     },
     {   'name'       => 'bulk_sleep',
@@ -475,7 +475,7 @@ our @params = (
         'default'    => '/usr/sbin/sendmail',
         'gettext_id' => 'Path to sendmail',
         'gettext_comment' =>
-            "Absolute path to sendmail command line utility (e.g.: a binary named \"sendmail\" is distributed with Postfix).\nSympa expects this binary to be sendmail compatible (exim, Postfix, qmail and so on provide it). Sympa also bundles \"sympa_smtpc\" program which may be a replacement to sendmail binary.",
+            "Absolute path to sendmail command line utility (e.g.: a binary named \"sendmail\" is distributed with Postfix).\nSympa expects this binary to be sendmail compatible (exim, Postfix, qmail and so on provide it).",
         'file' => 'sympa.conf',
         'edit' => '1',
     },
@@ -483,7 +483,7 @@ our @params = (
         'default'    => '-oi -odi -oem',
         'gettext_id' => 'Command line parameters passed to sendmail',
         'gettext_comment' =>
-            "Note that \"-f\", \"-N\" and \"-V\" options and recipient addresses need not included, because they will be included by Sympa.\nNote: If the path to sympa_smtpc is set as a value of \"sendmail\" parameter, \"--esmtp\" or \"--lmtp\" option is required.",
+            "Note that \"-f\", \"-N\" and \"-V\" options and recipient addresses need not included, because they will be included by Sympa.",
     },
     {   'name'       => 'log_smtp',
         'gettext_id' => 'Log invocation of sendmail',
@@ -573,14 +573,14 @@ our @params = (
     },
     {   'name'       => 'owner_domain_min',
         'sample'     => '1',
-        'gettext_id' => 'Minimum number of list owners that must match owner_domain restriction',
+        'gettext_id' => 'Minimum number of owners for each list that must match owner_domain restriction',
         'file'       => 'sympa.conf',
         'default'    => '0',
         'optional'   => '1',
         'vhost'      => '1',
         'edit'       => '1',
         'gettext_comment' =>
-            'Minimum number of list owners that must satisfy the owner_domain restriction.  The default of zero (0) means *all* list owners must match. Setting to 1 requires only one list owner to match owner_domain; all other owners can be from any domain. This setting can be used to ensure that there is always at least one known contact point for a mailing list.',
+            'Minimum number of owners for each list must satisfy the owner_domain restriction. The default of zero (0) means *all* list owners must match. Setting to 1 requires only one list owner to match owner_domain; all other owners can be from any domain. This setting can be used to ensure that there is always at least one known contact point for any mailing list.',
     },
 
     {'gettext_id' => 'Archives'},
@@ -595,7 +595,7 @@ our @params = (
         'edit'  => '1',
     },
     {   'name'         => 'default_archive_quota',
-        'gettext_id'   => 'Default disk quota for lists\' archive',
+        'gettext_id'   => 'Default disk quota for lists\' archives',
         'gettext_unit' => 'Kbytes',
         'optional'     => '1',
     },
@@ -678,7 +678,7 @@ our @params = (
     {   'name'       => 'tracking_default_retention_period',
         'gettext_id' => 'Max age of tracking information',
         'gettext_comment' =>
-            'Tracking information are removed after this number of days',
+            'Tracking information is removed after this number of days',
         'gettext_unit' => 'days',
         'default'      => '90',
     },
@@ -768,7 +768,7 @@ our @params = (
     {   'name'       => 'return_path_suffix',
         'gettext_id' => 'Suffix of list return address',
         'gettext_comment' =>
-            'The suffix appended to the list name to consist the return-path of messages distributed through the list. This address will receive all non-delivery reports (also called bounces).',
+            'The suffix appended to the list name to form the return-path of messages distributed through the list. This address will receive all non-delivery reports (also called bounces).',
         'default' => '-owner',
     },
 
@@ -844,7 +844,7 @@ our @params = (
             'name=family_one:prefix=f1:display=My automatic lists:prefix_separator=+:classes separator=-:family_owners_list=alist@domain.tld;name=family_two:prefix=f2:display=My other automatic lists:prefix_separator=+:classes separator=-:family_owners_list=anotherlist@domain.tld;',
         'gettext_id' => 'Definition of automatic list families',
         'gettext_comment' =>
-            "Defines the families the automatic lists are based on. It is a character string structured as follows:\n* each family is separated from the other by a semi-column (;)\n* inside a family definition, each field is separated from the other by a column (:)\n* each field has the structure: \"<field name>=<filed value>\"\nBasically, each time Sympa uses the automatic lists families, the values defined in this parameter will be available in the family object.\n* for scenarios: [family->name]\n* for templates: [% family.name %]",
+            "Defines the families the automatic lists are based on. It is a character string structured as follows:\n* each family is separated from the other by a semicolon (;)\n* inside a family definition, each field is separated from the other by a colon (:)\n* each field has the structure: \"<field name>=<filed value>\"\nBasically, each time Sympa uses the automatic lists families, the values defined in this parameter will be available in the family object.\n* for scenarios: [family->name]\n* for templates: [% family.name %]",
         'file'     => 'sympa.conf',
         'optional' => '1',
         'vhost'    => '1',
@@ -899,7 +899,7 @@ our @params = (
         'default'    => 'x-spam-status',
         'gettext_id' => 'Name of header field to inform',
         'gettext_comment' =>
-            'Messages are supposed to be filtered by an spam filter that add one more headers to messages. This parameter is used to select a special scenario in order to decide the message spam status: ham, spam or unsure. This parameter replace antispam_tag_header_name, antispam_tag_header_spam_regexp and antispam_tag_header_ham_regexp.',
+            'Messages are supposed to be filtered by an spam filter that adds them one or more headers. This parameter is used to select a special scenario in order to decide the message\'s spam status: ham, spam or unsure. This parameter replaces antispam_tag_header_name, antispam_tag_header_spam_regexp and antispam_tag_header_ham_regexp.',
         'vhost'    => '1',
         'file'     => 'sympa.conf',
         'edit'     => '1',
@@ -941,7 +941,7 @@ our @params = (
         'default_s'  => '$SPOOLDIR/msg',
         'gettext_id' => 'Directory for message incoming spool',
         'gettext_comment' =>
-            'This spool is used both by "queue" program and "sympa_msg.pl" daemon."',
+            'This spool is used both by "queue" program and "sympa_msg.pl" daemon.',
         'file' => 'sympa.conf',
     },
     {   'name'       => 'queuemod',
@@ -1037,7 +1037,7 @@ our @params = (
         'file'       => 'wwsympa.conf',
         'edit'       => '1',
         'gettext_comment' =>
-            'Where to store HTML archives. This parameter is used by the "archived.pl" daemon. It is a good idea to install the archive outside the web document hierarchy to ensure accesses passing WWSympa\'s access control will be prevented.',
+            'Where to store HTML archives. This parameter is used by the "archived.pl" daemon. It is a good idea to install the archive outside the web document hierarchy to prevent overcoming of WWSympa\'s access control.',
         'vhost' => 1,
     },
 
@@ -1151,7 +1151,7 @@ our @params = (
 ##        'file'     => 'wwsympa.conf',
 ##    },
 
-    {'gettext_id' => 'Miscelaneous'},
+    {'gettext_id' => 'Miscellaneous'},
 
     {   'name'       => 'email',
         'default'    => 'sympa',
@@ -1202,7 +1202,7 @@ our @params = (
     {   'name'       => 'purge_user_table_task',
         'gettext_id' => 'Task for expiring inactive users',
         'gettext_comment' =>
-            'This task removes rows in the "user_table" table which hove not corresponding entries in the "subscriber_table" table.',
+            'This task removes rows in the "user_table" table which have not corresponding entries in the "subscriber_table" table.',
         'default' => 'monthly',
     },
     {   'name'       => 'purge_logs_table_task',
@@ -1306,18 +1306,26 @@ our @params = (
         'optional'        => '1',
     },
     {   'name'       => 'css_path',
+        'default_s'  => '$CSSDIR',
         'gettext_id' => 'Directory for static style sheets (CSS)',
         'gettext_comment' =>
             'After an upgrade, static CSS files are upgraded with the newly installed "css.tt2" template. Therefore, this is not a good place to store customized CSS files.',
-        'optional' => '1',
-        'vhost'    => '1',
     },
     {   'name'       => 'css_url',
+        'default'    => '/static-sympa/css',
         'gettext_id' => 'URL for style sheets (CSS)',
         'gettext_comment' =>
             'To use auto-generated static CSS, HTTP server have to map it with "css_path".',
-        'optional' => '1',
-        'vhost'    => '1',
+    },
+    {   'name'       => 'pictures_path',
+        'default_s'  => '$PICTURESDIR',
+        'gettext_id' => 'Directory for subscribers pictures',
+    },
+    {   'name'       => 'pictures_url',
+        'default'    => '/static-sympa/pictures',
+        'gettext_id' => 'URL for subscribers pictures',
+        'gettext_comment' =>
+            'HTTP server have to map it with "pictures_path" directory.',
     },
     {   'name'       => 'color_0',
         'gettext_id' => 'Colors for web interface',
@@ -1475,7 +1483,7 @@ our @params = (
     {   'name'       => 'main_menu_custom_button_1_title',
         'gettext_id' => 'Custom menus',
         'gettext_comment' =>
-            'You may modify the main menu content by editing the menu.tt2 file but you can also edit the these parameters in order to add up to 3 button. Each button is defined by a title (the text in the button), an URL and optionally a target.',
+            'You may modify the main menu content by editing the menu.tt2 file, but you can also edit these parameters in order to add up to 3 buttons. Each button is defined by a title (the text in the button), an URL and, optionally, a target.',
         'sample'   => 'FAQ',
         'optional' => '1',
         'vhost'    => '1',
@@ -1515,7 +1523,7 @@ our @params = (
         'vhost'    => '1',
     },
 
-    {'gettext_id' => 'Web interface parameters: Miscelaneous'},
+    {'gettext_id' => 'Web interface parameters: Miscellaneous'},
 
     # Session and cookie:
 
@@ -1532,7 +1540,7 @@ our @params = (
         'default'    => '0',
         'gettext_id' => 'HTTP cookies lifetime',
         'gettext_comment' =>
-            'This is the default value when not set explicitly by users. "0" means the cookie may be retained during browser session.',
+            'This is the default value when not set explicitly by users. "0" means the cookie may be retained during browser sessions.',
         'file' => 'wwsympa.conf',
     },
     {   'name'       => 'cookie_refresh',
@@ -1625,6 +1633,30 @@ our @params = (
         'gettext_comment' =>
             "\"insensitive\" or \"sensitive\".\nIf set to \"insensitive\", WWSympa's password check will be insensitive. This only concerns passwords stored in the Sympa database, not the ones in LDAP.\nShould not be changed! May invalid all user password.",
     },
+    {   'name'       => 'password_hash',
+        'default'    => 'md5',
+        'gettext_id' => 'Password hashing algorithm',
+        'file'       => 'wwsympa.conf',
+        #vhost      => '1', # per-robot config is impossible.
+        'gettext_comment' =>
+            "\"md5\" or \"bcrypt\".\nIf set to \"md5\", Sympa will use MD5 password hashes. If set to \"bcrypt\", bcrypt hashes will be used instead. This only concerns passwords stored in the Sympa database, not the ones in LDAP.\nShould not be changed! May invalid all user passwords.",
+    },
+    {   'name'       => 'password_hash_update',
+        'default'    => '1',
+        'gettext_id' => 'Update password hashing algorithm when users log in',
+        'file'       => 'wwsympa.conf',
+        #vhost      => '1', # per-robot config is impossible.
+        'gettext_comment' =>
+            "On successful login, update the encrypted user password to use the algorithm specified by \"password_hash\". This allows for a graceful transition to a new password hash algorithm. A value of 0 disables updating of existing password hashes.  New and reset passwords will use the \"password_hash\" setting in all cases.",
+    },
+    {   'name'       => 'bcrypt_cost',
+        'default'    => '12',
+        'gettext_id' => 'Bcrypt hash cost',
+        'file'       => 'wwsympa.conf',
+        #vhost      => '1', # per-robot config is impossible.
+        'gettext_comment' =>
+            "When \"password_hash\" is set to \"bcrypt\", this sets the \"cost\" parameter of the bcrypt hash function. The default of 12 is expected to require approximately 250ms to calculate the password hash on a 3.2GHz CPU. This only concerns passwords stored in the Sympa database, not the ones in LDAP.\nCan be changed but any new cost setting will only apply to new passwords.",
+    },
 
     # One time ticket
 
@@ -1656,6 +1688,7 @@ our @params = (
         'gettext_comment' =>
             "Enables or disables the pictures feature by default.  If enabled, subscribers can upload their picture (from the \"Subscriber option\" page) to use as an avatar.\nPictures are stored in a directory specified by the \"static_content_path\" parameter.",
         'default' => 'on',
+        'vhost'   => '1',
     },
     {   'name'         => 'pictures_max_size',
         'gettext_id'   => 'The maximum size of uploaded picture',
@@ -1744,7 +1777,7 @@ our @params = (
 
     {   'gettext_id' => 'Data sources setup',
         'gettext_comment' =>
-            'Including subscribers, owners and editors from datasources. Appropriate database driver (DBD) modules are required: DBD-CSV, DBD-mysql, DBD-ODBC, DBD-Oracle, DBD-Pg, DBD-SQLite, DBD-Sybase and/or Net-LDAP. And also, if secure connection (LDAPS) to LDAP server is required: IO-SOcket-SSL.',
+            'Including subscribers, owners and editors from datasources. Appropriate database driver (DBD) modules are required: DBD-CSV, DBD-mysql, DBD-ODBC, DBD-Oracle, DBD-Pg, DBD-SQLite, DBD-Sybase and/or Net-LDAP. And also, if secure connection (LDAPS) to LDAP server is required: IO-Socket-SSL.',
     },
 
     {   'name'       => 'default_sql_fetch_timeout',
@@ -1754,6 +1787,13 @@ our @params = (
         'file'    => 'sympa.conf',
         'default' => '300',
     },
+    {   'name'       => 'default_ttl',
+        'gettext_id' => 'Default of inclusion timeout',
+        'gettext_comment' =>
+            'Default timeout between two scheduled synchronizations of list members with data sources.',
+        'file'    => 'sympa.conf',
+        'default' => '3600',
+    },
 
     {   'gettext_id' => 'DKIM',
         'gettext_comment' =>
@@ -1799,7 +1839,7 @@ our @params = (
         'vhost'      => '1',
         'gettext_id' => 'The "d=" tag as defined in rfc 4871',
         'gettext_comment' =>
-            'The DKIM "d=" tag, is the domain of the signing entity. Default is virtual host domain name',
+            'The DKIM "d=" tag is the domain of the signing entity. The virtual host domain name is used as its default value',
         'optional' => '1',
         'file'     => 'sympa.conf',
     },
@@ -1831,7 +1871,7 @@ our @params = (
 
     {   'gettext_id' => 'DMARC protection',
         'gettext_comment' =>
-            'Processes originator addresses to avoid some domains\' excessive DMARC protection.  This feature requires external module: Net-DNS.',
+            'Processes originator addresses to avoid some domains\' excessive DMARC protection. This feature requires an external module: Net-DNS.',
     },
 
     {   'name'       => 'dmarc_protection_mode',
@@ -1869,7 +1909,7 @@ our @params = (
 
     {   'gettext_id' => 'List address verification',
         'gettext_comment' =>
-            'Checks if ailias with the same name as the list to be created already exists on the SMTP server. This feature requires external module: Net-SMTP.',
+            'Checks if an alias with the same name as the list to be created already exists on the SMTP server. This feature requires an external module: Net-SMTP.',
     },
 
     {   'name'     => 'list_check_helo',
@@ -1930,7 +1970,7 @@ our @params = (
 
     {   'gettext_id' => 'Password validation',
         'gettext_comment' =>
-            'Checks if the password the users sbmitted has sufficient strength. This feature requires external module: Data-Password.',
+            'Checks if the password the user submitted has sufficient strength. This feature requires an external module: Data-Password.',
     },
 
     {   'name'       => 'password_validation',
@@ -1946,7 +1986,7 @@ our @params = (
 
     {   'gettext_id' => 'Authentication with LDAP',
         'gettext_comment' =>
-            'Authnticates users based on the directory on LDAP server. This feature requires external module: Net-LDAP. And also, if secure connection (LDAPS) is required: IO-Socket-SSL.',
+            'Authenticates users based on the directory on LDAP server. This feature requires an external module: Net-LDAP. And also, if secure connection (LDAPS) is required: IO-Socket-SSL.',
     },
 
     {   'name'       => 'ldap_force_canonical_email',
@@ -1960,7 +2000,7 @@ our @params = (
 
     {   'gettext_id' => 'SOAP HTTP interface',
         'gettext_comment' =>
-            'Provides some functions of Sympa through SOAP HTTP interface. This feature requires external module: SOAP-Lite.',
+            'Provides some functions of Sympa through the SOAP HTTP interface. This feature requires an external module: SOAP-Lite.',
     },
 
     {   'name'       => 'soap_url',
@@ -2012,12 +2052,6 @@ our @params = (
         'file'     => 'sympa.conf',
         'optional' => '1',
     },
-    {   'name' => 'default_ttl',    #FIXME: maybe not used
-        'gettext_id' =>
-            'Default timeout between two scheduled synchronizations of list members with data sources.',
-        'file'    => 'sympa.conf',
-        'default' => '3600',
-    },
     {   'name' => 'default_distribution_ttl',    #FIXME: maybe not used
         'gettext_id' =>
             'Default timeout between two action-triggered synchronizations of list members with data sources.',
@@ -2039,7 +2073,7 @@ our @params = (
         'file'       => 'wwsympa.conf',
         'edit'       => '1',
         'gettext_comment' =>
-            'Is FastCGI module for HTTP server installed. This module provide much faster web interface.',
+            'Is FastCGI module for HTTP server installed? This module provides a much faster web interface.',
     },
 
 ## Not implemented yet.
