@@ -8,8 +8,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017 The Sympa Community. See the AUTHORS.md file at the top-level
-# directory of this distribution and at
+# Copyright 2017, 2018 The Sympa Community. See the AUTHORS.md file at the
+# top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -345,6 +345,12 @@ sub modify_list {
     }
 
     my $hash_list = $config->getHash();
+    # Compatibility: single topic on 6.2.24 or earlier.
+    $hash_list->{config}{topics} ||= $hash_list->{config}{topic};
+    # In old documentation "moderator" was single or multiple editors.
+    my $mod = $hash_list->{config}{moderator};
+    $hash_list->{config}{editor} ||=
+        (ref $mod eq 'ARRAY') ? $mod : (ref $mod eq 'HASH') ? [$mod] : [];
 
     #getting list
     my $list;
@@ -874,6 +880,12 @@ sub instantiate {
 
         ## stores the list config into the hash referenced by $hash_list.
         my $hash_list = $config->getHash();
+        # Compatibility: single topic on 6.2.24 or earlier.
+        $hash_list->{config}{topics} ||= $hash_list->{config}{topic};
+        # In old documentation "moderator" was single or multiple editors.
+        my $mod = $hash_list->{config}{moderator};
+        $hash_list->{config}{editor} ||=
+            (ref $mod eq 'ARRAY') ? $mod : (ref $mod eq 'HASH') ? [$mod] : [];
 
         if ($list) {
             ## LIST ALREADY EXISTING
@@ -1056,6 +1068,12 @@ sub instantiate {
                 next;
             }
             my $hash_list = $config->getHash();
+            # Compatibility: single topic on 6.2.24 or earlier.
+            $hash_list->{config}{topics} ||= $hash_list->{config}{topic};
+            # In old documentation "moderator" was single or multiple editors.
+            my $mod = $hash_list->{config}{moderator};
+            $hash_list->{config}{editor} ||=
+            (ref $mod eq 'ARRAY') ? $mod : (ref $mod eq 'HASH') ? [$mod] : [];
 
             my $result = $self->_update_existing_list($list, $hash_list);
             unless (defined $result) {
