@@ -301,7 +301,7 @@ and executed.  Otherwise messages will be skipped.
 
 =head2 Public methods
 
-See also L<Sympa::Spindle::Incoming/"Public methods">.
+See also L<Sympa::Spindle::ProcessIncoming/"Public methods">.
 
 =over
 
@@ -309,7 +309,7 @@ See also L<Sympa::Spindle::Incoming/"Public methods">.
 
 =item spin ( )
 
-In most cases, L<Sympa::Spindle::ProcessIncoming> splices meessages
+In most cases, L<Sympa::Spindle::ProcessIncoming> splices messages
 to this class.  These methods are not used in ordinal case.
 
 =back
